@@ -56,6 +56,18 @@ class BONE_PT_context_bone(BoneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -92,6 +104,12 @@ class BONE_PT_context_bone(BoneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -146,12 +164,24 @@ class BONE_PT_context_bone(BoneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -184,6 +214,9 @@ class BONE_PT_curved(BoneButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
     bl_label = None
     ''' '''
 
+    bl_options = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
@@ -208,6 +241,18 @@ class BONE_PT_curved(BoneButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -244,6 +289,12 @@ class BONE_PT_curved(BoneButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -298,12 +349,24 @@ class BONE_PT_curved(BoneButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -343,6 +406,9 @@ class BONE_PT_custom_props(BoneButtonsPanel, rna_prop_ui.PropertyPanel,
     bl_options = None
     ''' '''
 
+    bl_order = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
@@ -367,6 +433,18 @@ class BONE_PT_custom_props(BoneButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -403,6 +481,12 @@ class BONE_PT_custom_props(BoneButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -457,12 +541,24 @@ class BONE_PT_custom_props(BoneButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -522,6 +618,18 @@ class BONE_PT_deform(BoneButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -564,6 +672,12 @@ class BONE_PT_deform(BoneButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -618,12 +732,24 @@ class BONE_PT_deform(BoneButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -656,6 +782,9 @@ class BONE_PT_display(BoneButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
     bl_label = None
     ''' '''
 
+    bl_options = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
@@ -680,6 +809,18 @@ class BONE_PT_display(BoneButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -716,6 +857,12 @@ class BONE_PT_display(BoneButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -770,12 +917,24 @@ class BONE_PT_display(BoneButtonsPanel, bpy_types.Panel, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -836,6 +995,18 @@ class BONE_PT_inverse_kinematics(BoneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -872,6 +1043,12 @@ class BONE_PT_inverse_kinematics(BoneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -926,12 +1103,24 @@ class BONE_PT_inverse_kinematics(BoneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -965,6 +1154,9 @@ class BONE_PT_relations(BoneButtonsPanel, bpy_types.Panel,
     bl_label = None
     ''' '''
 
+    bl_options = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
@@ -989,6 +1181,18 @@ class BONE_PT_relations(BoneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -1025,6 +1229,12 @@ class BONE_PT_relations(BoneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1079,12 +1289,24 @@ class BONE_PT_relations(BoneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1142,6 +1364,18 @@ class BONE_PT_transform(BoneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -1178,6 +1412,12 @@ class BONE_PT_transform(BoneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1232,163 +1472,19 @@ class BONE_PT_transform(BoneButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
-    def property_unset(self):
-        ''' 
-
-        '''
-        pass
-
-    def remove(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def type_recast(self):
-        ''' 
-
-        '''
-        pass
-
-    def values(self):
-        ''' 
-
-        '''
-        pass
-
-
-class BONE_PT_transform_locks(BoneButtonsPanel, bpy_types.Panel,
-                              bpy_types._GenericUI):
-    bl_context = None
-    ''' '''
-
-    bl_label = None
-    ''' '''
-
-    bl_options = None
-    ''' '''
-
-    bl_region_type = None
-    ''' '''
-
-    bl_rna = None
-    ''' '''
-
-    bl_space_type = None
-    ''' '''
-
-    id_data = None
-    ''' '''
-
-    def append(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def as_pointer(self):
-        ''' 
-
-        '''
-        pass
-
-    def draw(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def driver_add(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_remove(self):
-        ''' 
-
-        '''
-        pass
-
-    def get(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_extended(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_hidden(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_readonly(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def items(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_delete(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_insert(self):
-        ''' 
-
-        '''
-        pass
-
-    def keys(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_from_id(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_resolve(self):
-        ''' 
-
-        '''
-        pass
-
-    def poll(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def prepend(self, draw_func):
+    def property_overridable_library_set(self):
         ''' 
 
         '''
