@@ -3,7 +3,88 @@ import typing
 import bpy_types
 
 
-class GPENCIL_MT_brush_specials(bpy_types.Menu, bpy_types._GenericUI):
+class AnnotationDataPanel:
+    bl_label = None
+    ''' '''
+
+    bl_options = None
+    ''' '''
+
+    bl_region_type = None
+    ''' '''
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def draw_header(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def draw_layers(self, context, layout, gpd):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+
+class AnnotationDrawingToolsPanel:
+    bl_category = None
+    ''' '''
+
+    bl_label = None
+    ''' '''
+
+    bl_region_type = None
+    ''' '''
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+
+class AnnotationOnionSkin:
+    bl_label = None
+    ''' '''
+
+    bl_options = None
+    ''' '''
+
+    bl_region_type = None
+    ''' '''
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def draw_header(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+
+class GPENCIL_MT_cleanup(bpy_types.Menu, bpy_types._GenericUI):
     bl_label = None
     ''' '''
 
@@ -25,6 +106,18 @@ class GPENCIL_MT_brush_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -37,7 +130,7 @@ class GPENCIL_MT_brush_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -73,6 +166,12 @@ class GPENCIL_MT_brush_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -116,7 +215,7 @@ class GPENCIL_MT_brush_specials(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -128,12 +227,24 @@ class GPENCIL_MT_brush_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -159,7 +270,7 @@ class GPENCIL_MT_brush_specials(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
 
-class GPENCIL_MT_gpencil_edit_specials(bpy_types.Menu, bpy_types._GenericUI):
+class GPENCIL_MT_gpencil_draw_delete(bpy_types.Menu, bpy_types._GenericUI):
     bl_label = None
     ''' '''
 
@@ -181,7 +292,19 @@ class GPENCIL_MT_gpencil_edit_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw(self, context):
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, _context):
         ''' 
 
         '''
@@ -193,7 +316,7 @@ class GPENCIL_MT_gpencil_edit_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -229,6 +352,12 @@ class GPENCIL_MT_gpencil_edit_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -272,7 +401,7 @@ class GPENCIL_MT_gpencil_edit_specials(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -284,12 +413,24 @@ class GPENCIL_MT_gpencil_edit_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -315,7 +456,7 @@ class GPENCIL_MT_gpencil_edit_specials(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
 
-class GPENCIL_MT_layer_specials(bpy_types.Menu, bpy_types._GenericUI):
+class GPENCIL_MT_move_to_layer(bpy_types.Menu, bpy_types._GenericUI):
     bl_label = None
     ''' '''
 
@@ -337,6 +478,18 @@ class GPENCIL_MT_layer_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -349,7 +502,7 @@ class GPENCIL_MT_layer_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -385,6 +538,12 @@ class GPENCIL_MT_layer_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -428,7 +587,7 @@ class GPENCIL_MT_layer_specials(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -440,12 +599,24 @@ class GPENCIL_MT_layer_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -471,7 +642,7 @@ class GPENCIL_MT_layer_specials(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
 
-class GPENCIL_MT_palettecolor_specials(bpy_types.Menu, bpy_types._GenericUI):
+class GPENCIL_MT_pie_sculpt(bpy_types.Menu, bpy_types._GenericUI):
     bl_label = None
     ''' '''
 
@@ -493,6 +664,18 @@ class GPENCIL_MT_palettecolor_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -505,7 +688,7 @@ class GPENCIL_MT_palettecolor_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -541,6 +724,12 @@ class GPENCIL_MT_palettecolor_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -584,7 +773,7 @@ class GPENCIL_MT_palettecolor_specials(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -596,12 +785,600 @@ class GPENCIL_MT_palettecolor_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class GPENCIL_MT_pie_settings_palette(bpy_types.Menu, bpy_types._GenericUI):
+    bl_label = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def draw_collapsible(self, context, layout):
+        ''' 
+
+        '''
+        pass
+
+    def draw_preset(self, _context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name, add_operator):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class GPENCIL_MT_pie_tool_palette(bpy_types.Menu, bpy_types._GenericUI):
+    bl_label = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def draw_collapsible(self, context, layout):
+        ''' 
+
+        '''
+        pass
+
+    def draw_preset(self, _context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name, add_operator):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class GPENCIL_MT_pie_tools_more(bpy_types.Menu, bpy_types._GenericUI):
+    bl_label = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, _context):
+        ''' 
+
+        '''
+        pass
+
+    def draw_collapsible(self, context, layout):
+        ''' 
+
+        '''
+        pass
+
+    def draw_preset(self, _context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name, add_operator):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -649,7 +1426,19 @@ class GPENCIL_MT_snap(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw(self, context):
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, _context):
         ''' 
 
         '''
@@ -661,7 +1450,7 @@ class GPENCIL_MT_snap(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -697,6 +1486,12 @@ class GPENCIL_MT_snap(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -740,7 +1535,7 @@ class GPENCIL_MT_snap(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -752,12 +1547,24 @@ class GPENCIL_MT_snap(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -783,10 +1590,7 @@ class GPENCIL_MT_snap(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
 
-class GPENCIL_PIE_sculpt(bpy_types.Menu, bpy_types._GenericUI):
-    bl_label = None
-    ''' '''
-
+class GPENCIL_UL_annotation_layer(bpy_types.UIList, bpy_types._GenericUI):
     bl_rna = None
     ''' '''
 
@@ -805,19 +1609,20 @@ class GPENCIL_PIE_sculpt(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw(self, context):
+    def bl_rna_get_subclass(self):
         ''' 
 
         '''
         pass
 
-    def draw_collapsible(self, context, layout):
+    def bl_rna_get_subclass_py(self):
         ''' 
 
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_item(self, _context, layout, _data, item, icon, _active_data,
+                  _active_propname, _index):
         ''' 
 
         '''
@@ -853,629 +1658,7 @@ class GPENCIL_PIE_sculpt(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def is_property_readonly(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def items(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_delete(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_insert(self):
-        ''' 
-
-        '''
-        pass
-
-    def keys(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_from_id(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
-        ''' 
-
-        '''
-        pass
-
-    def path_resolve(self):
-        ''' 
-
-        '''
-        pass
-
-    def poll(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def prepend(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def property_unset(self):
-        ''' 
-
-        '''
-        pass
-
-    def remove(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def type_recast(self):
-        ''' 
-
-        '''
-        pass
-
-    def values(self):
-        ''' 
-
-        '''
-        pass
-
-
-class GPENCIL_PIE_settings_palette(bpy_types.Menu, bpy_types._GenericUI):
-    bl_label = None
-    ''' '''
-
-    bl_rna = None
-    ''' '''
-
-    id_data = None
-    ''' '''
-
-    def append(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def as_pointer(self):
-        ''' 
-
-        '''
-        pass
-
-    def draw(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def draw_collapsible(self, context, layout):
-        ''' 
-
-        '''
-        pass
-
-    def draw_preset(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def driver_add(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_remove(self):
-        ''' 
-
-        '''
-        pass
-
-    def get(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_extended(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_hidden(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_readonly(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def items(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_delete(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_insert(self):
-        ''' 
-
-        '''
-        pass
-
-    def keys(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_from_id(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
-        ''' 
-
-        '''
-        pass
-
-    def path_resolve(self):
-        ''' 
-
-        '''
-        pass
-
-    def poll(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def prepend(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def property_unset(self):
-        ''' 
-
-        '''
-        pass
-
-    def remove(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def type_recast(self):
-        ''' 
-
-        '''
-        pass
-
-    def values(self):
-        ''' 
-
-        '''
-        pass
-
-
-class GPENCIL_PIE_tool_palette(bpy_types.Menu, bpy_types._GenericUI):
-    bl_label = None
-    ''' '''
-
-    bl_rna = None
-    ''' '''
-
-    id_data = None
-    ''' '''
-
-    def append(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def as_pointer(self):
-        ''' 
-
-        '''
-        pass
-
-    def draw(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def draw_collapsible(self, context, layout):
-        ''' 
-
-        '''
-        pass
-
-    def draw_preset(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def driver_add(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_remove(self):
-        ''' 
-
-        '''
-        pass
-
-    def get(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_extended(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_hidden(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_readonly(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def items(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_delete(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_insert(self):
-        ''' 
-
-        '''
-        pass
-
-    def keys(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_from_id(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
-        ''' 
-
-        '''
-        pass
-
-    def path_resolve(self):
-        ''' 
-
-        '''
-        pass
-
-    def prepend(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def property_unset(self):
-        ''' 
-
-        '''
-        pass
-
-    def remove(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def type_recast(self):
-        ''' 
-
-        '''
-        pass
-
-    def values(self):
-        ''' 
-
-        '''
-        pass
-
-
-class GPENCIL_PIE_tools_more(bpy_types.Menu, bpy_types._GenericUI):
-    bl_label = None
-    ''' '''
-
-    bl_rna = None
-    ''' '''
-
-    id_data = None
-    ''' '''
-
-    def append(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def as_pointer(self):
-        ''' 
-
-        '''
-        pass
-
-    def draw(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def draw_collapsible(self, context, layout):
-        ''' 
-
-        '''
-        pass
-
-    def draw_preset(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def driver_add(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_remove(self):
-        ''' 
-
-        '''
-        pass
-
-    def get(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_extended(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_hidden(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_readonly(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def items(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_delete(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_insert(self):
-        ''' 
-
-        '''
-        pass
-
-    def keys(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_from_id(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
-        ''' 
-
-        '''
-        pass
-
-    def path_resolve(self):
-        ''' 
-
-        '''
-        pass
-
-    def poll(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def prepend(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def property_unset(self):
-        ''' 
-
-        '''
-        pass
-
-    def remove(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def type_recast(self):
-        ''' 
-
-        '''
-        pass
-
-    def values(self):
-        ''' 
-
-        '''
-        pass
-
-
-class GPENCIL_UL_brush(bpy_types.UIList, bpy_types._GenericUI):
-    bl_rna = None
-    ''' '''
-
-    id_data = None
-    ''' '''
-
-    def append(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def as_pointer(self):
-        ''' 
-
-        '''
-        pass
-
-    def draw_item(self, context, layout, data, item, icon, active_data,
-                  active_propname, index):
-        ''' 
-
-        '''
-        pass
-
-    def driver_add(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_remove(self):
-        ''' 
-
-        '''
-        pass
-
-    def get(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_extended(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_hidden(self):
+    def is_property_overridable_library(self):
         ''' 
 
         '''
@@ -1529,12 +1712,24 @@ class GPENCIL_UL_brush(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1579,8 +1774,20 @@ class GPENCIL_UL_layer(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_item(self, context, layout, data, item, icon, active_data,
-                  active_propname, index):
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw_item(self, _context, layout, _data, item, icon, _active_data,
+                  _active_propname, _index):
         ''' 
 
         '''
@@ -1616,6 +1823,12 @@ class GPENCIL_UL_layer(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1664,12 +1877,24 @@ class GPENCIL_UL_layer(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1695,191 +1920,13 @@ class GPENCIL_UL_layer(bpy_types.UIList, bpy_types._GenericUI):
         pass
 
 
-class GPENCIL_UL_palettecolor(bpy_types.UIList, bpy_types._GenericUI):
-    bl_rna = None
-    ''' '''
-
-    id_data = None
-    ''' '''
-
-    def append(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def as_pointer(self):
-        ''' 
-
-        '''
-        pass
-
-    def draw_item(self, context, layout, data, item, icon, active_data,
-                  active_propname, index):
-        ''' 
-
-        '''
-        pass
-
-    def driver_add(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_remove(self):
-        ''' 
-
-        '''
-        pass
-
-    def get(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_extended(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_hidden(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_readonly(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def items(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_delete(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_insert(self):
-        ''' 
-
-        '''
-        pass
-
-    def keys(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_from_id(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_resolve(self):
-        ''' 
-
-        '''
-        pass
-
-    def prepend(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def property_unset(self):
-        ''' 
-
-        '''
-        pass
-
-    def remove(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def type_recast(self):
-        ''' 
-
-        '''
-        pass
-
-    def values(self):
-        ''' 
-
-        '''
-        pass
-
-
-class GreasePencilBrushCurvesPanel:
-    bl_category = None
-    ''' '''
-
+class GreasePencilDisplayPanel:
     bl_label = None
     ''' '''
 
     bl_options = None
     ''' '''
 
-    bl_region_type = None
-    ''' '''
-
-    def draw(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def poll(self, context):
-        ''' 
-
-        '''
-        pass
-
-
-class GreasePencilBrushPanel:
-    bl_category = None
-    ''' '''
-
-    bl_label = None
-    ''' '''
-
-    bl_region_type = None
-    ''' '''
-
-    def draw(self, context):
-        ''' 
-
-        '''
-        pass
-
-
-class GreasePencilDataPanel:
-    bl_label = None
-    ''' '''
-
-    bl_region_type = None
-    ''' '''
-
     def draw(self, context):
         ''' 
 
@@ -1892,29 +1939,14 @@ class GreasePencilDataPanel:
         '''
         pass
 
-    def draw_layer(self, context, layout, gpl):
-        ''' 
-
-        '''
-        pass
-
-    def draw_layers(self, context, layout, gpd):
+    def poll(self, context):
         ''' 
 
         '''
         pass
 
 
-class GreasePencilDrawingToolsPanel:
-    bl_category = None
-    ''' '''
-
-    bl_label = None
-    ''' '''
-
-    bl_region_type = None
-    ''' '''
-
+class GreasePencilLayerAdjustmentsPanel:
     def draw(self, context):
         ''' 
 
@@ -1922,22 +1954,34 @@ class GreasePencilDrawingToolsPanel:
         pass
 
 
-class GreasePencilInterpolatePanel:
-    bl_category = None
-    ''' '''
+class GreasePencilLayerDisplayPanel:
+    def draw(self, context):
+        ''' 
 
+        '''
+        pass
+
+
+class GreasePencilLayerRelationsPanel:
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+
+class GreasePencilMaterialsPanel:
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+
+class GreasePencilSculptOptionsPanel:
     bl_label = None
     ''' '''
 
-    bl_options = None
-    ''' '''
-
-    bl_region_type = None
-    ''' '''
-
-    bl_space_type = None
-    ''' '''
-
     def draw(self, context):
         ''' 
 
@@ -1951,75 +1995,14 @@ class GreasePencilInterpolatePanel:
         pass
 
 
-class GreasePencilPaletteColorPanel:
-    bl_label = None
-    ''' '''
-
-    bl_region_type = None
-    ''' '''
-
+class GreasePencilSimplifyPanel:
     def draw(self, context):
         ''' 
 
         '''
         pass
 
-    def draw_palettecolors(self, layout, pcolor):
-        ''' 
-
-        '''
-        pass
-
-    def poll(self, context):
-        ''' 
-
-        '''
-        pass
-
-
-class GreasePencilStrokeEditPanel:
-    bl_category = None
-    ''' '''
-
-    bl_label = None
-    ''' '''
-
-    bl_options = None
-    ''' '''
-
-    bl_region_type = None
-    ''' '''
-
-    def draw(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def poll(self, context):
-        ''' 
-
-        '''
-        pass
-
-
-class GreasePencilStrokeSculptPanel:
-    bl_category = None
-    ''' '''
-
-    bl_label = None
-    ''' '''
-
-    bl_region_type = None
-    ''' '''
-
-    def draw(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def poll(self, context):
+    def draw_header(self, context):
         ''' 
 
         '''
@@ -2030,6 +2013,9 @@ class GreasePencilToolsPanel:
     bl_label = None
     ''' '''
 
+    bl_options = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
@@ -2039,7 +2025,7 @@ class GreasePencilToolsPanel:
         '''
         pass
 
-    def poll(self, context):
+    def poll(self, _context):
         ''' 
 
         '''
