@@ -3,13 +3,19 @@ import typing
 import bpy_types
 
 
-class MASK_MT_animation(bpy_types.Menu, bpy_types._GenericUI):
+class MASK_MT_add(bpy_types.Menu, bpy_types._GenericUI):
+    bl_idname = None
+    ''' '''
+
     bl_label = None
     ''' '''
 
     bl_rna = None
     ''' '''
 
+    bl_translation_context = None
+    ''' '''
+
     id_data = None
     ''' '''
 
@@ -25,7 +31,19 @@ class MASK_MT_animation(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw(self, context):
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, _context):
         ''' 
 
         '''
@@ -37,7 +55,7 @@ class MASK_MT_animation(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -73,6 +91,12 @@ class MASK_MT_animation(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -116,7 +140,7 @@ class MASK_MT_animation(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -128,12 +152,210 @@ class MASK_MT_animation(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class MASK_MT_animation(bpy_types.Menu, bpy_types._GenericUI):
+    bl_label = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, _context):
+        ''' 
+
+        '''
+        pass
+
+    def draw_collapsible(self, context, layout):
+        ''' 
+
+        '''
+        pass
+
+    def draw_preset(self, _context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name, add_operator):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -181,7 +403,19 @@ class MASK_MT_mask(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw(self, context):
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, _context):
         ''' 
 
         '''
@@ -193,7 +427,7 @@ class MASK_MT_mask(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -229,6 +463,12 @@ class MASK_MT_mask(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -272,7 +512,7 @@ class MASK_MT_mask(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -284,12 +524,24 @@ class MASK_MT_mask(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -337,7 +589,19 @@ class MASK_MT_select(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw(self, context):
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, _context):
         ''' 
 
         '''
@@ -349,7 +613,7 @@ class MASK_MT_select(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -385,6 +649,12 @@ class MASK_MT_select(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -428,7 +698,7 @@ class MASK_MT_select(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -440,12 +710,24 @@ class MASK_MT_select(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -493,7 +775,19 @@ class MASK_MT_transform(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw(self, context):
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, _context):
         ''' 
 
         '''
@@ -505,7 +799,7 @@ class MASK_MT_transform(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -541,6 +835,12 @@ class MASK_MT_transform(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -584,7 +884,7 @@ class MASK_MT_transform(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -596,12 +896,24 @@ class MASK_MT_transform(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -649,7 +961,19 @@ class MASK_MT_visibility(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw(self, context):
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, _context):
         ''' 
 
         '''
@@ -661,7 +985,7 @@ class MASK_MT_visibility(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -697,6 +1021,12 @@ class MASK_MT_visibility(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -740,7 +1070,7 @@ class MASK_MT_visibility(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -752,12 +1082,24 @@ class MASK_MT_visibility(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -783,26 +1125,6 @@ class MASK_MT_visibility(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
 
-class MASK_PT_add:
-    bl_category = None
-    ''' '''
-
-    bl_label = None
-    ''' '''
-
-    def draw(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def poll(self, context):
-        ''' 
-
-        '''
-        pass
-
-
 class MASK_PT_display:
     bl_label = None
     ''' '''
@@ -901,7 +1223,7 @@ class MASK_PT_tools:
     bl_label = None
     ''' '''
 
-    def draw(self, context):
+    def draw(self, _context):
         ''' 
 
         '''
@@ -921,10 +1243,7 @@ class MASK_PT_transforms:
     bl_label = None
     ''' '''
 
-    bl_options = None
-    ''' '''
-
-    def draw(self, context):
+    def draw(self, _context):
         ''' 
 
         '''
@@ -956,8 +1275,20 @@ class MASK_UL_layers(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_item(self, context, layout, data, item, icon, active_data,
-                  active_propname, index):
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw_item(self, _context, layout, _data, item, icon, _active_data,
+                  _active_propname, _index):
         ''' 
 
         '''
@@ -993,6 +1324,12 @@ class MASK_UL_layers(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1041,12 +1378,24 @@ class MASK_UL_layers(bpy_types.UIList, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1070,3 +1419,11 @@ class MASK_UL_layers(bpy_types.UIList, bpy_types._GenericUI):
 
         '''
         pass
+
+
+def draw_mask_context_menu(layout, context):
+    ''' 
+
+    '''
+
+    pass
