@@ -5,7 +5,7 @@ import rna_prop_ui
 import bl_ui.properties_animviz
 
 
-class GROUP_MT_specials(bpy_types.Menu, bpy_types._GenericUI):
+class COLLECTION_MT_context_menu(bpy_types.Menu, bpy_types._GenericUI):
     bl_label = None
     ''' '''
 
@@ -27,7 +27,19 @@ class GROUP_MT_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw(self, context):
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, _context):
         ''' 
 
         '''
@@ -39,7 +51,7 @@ class GROUP_MT_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_preset(self, context):
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -75,6 +87,12 @@ class GROUP_MT_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -118,7 +136,7 @@ class GROUP_MT_specials(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
     def path_menu(self, searchpaths, operator, props_default, prop_filepath,
-                  filter_ext, filter_path, display_name):
+                  filter_ext, filter_path, display_name, add_operator):
         ''' 
 
         '''
@@ -130,12 +148,24 @@ class GROUP_MT_specials(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -196,13 +226,25 @@ class OBJECT_PT_motion_paths(bl_ui.properties_animviz.MotionPathButtonsPanel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
         '''
         pass
 
-    def draw_settings(self, context, avs, mpath, bones):
+    def draw_settings(self, _context, avs, mpath, bones):
         ''' 
 
         '''
@@ -238,6 +280,12 @@ class OBJECT_PT_motion_paths(bl_ui.properties_animviz.MotionPathButtonsPanel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -292,12 +340,24 @@ class OBJECT_PT_motion_paths(bl_ui.properties_animviz.MotionPathButtonsPanel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -323,7 +383,9 @@ class OBJECT_PT_motion_paths(bl_ui.properties_animviz.MotionPathButtonsPanel,
         pass
 
 
-class OBJECT_PT_onion_skinning(bl_ui.properties_animviz.OnionSkinButtonsPanel):
+class OBJECT_PT_motion_paths_display(
+        bl_ui.properties_animviz.MotionPathButtonsPanel_display,
+        bpy_types.Panel, bpy_types._GenericUI):
     bl_context = None
     ''' '''
 
@@ -333,24 +395,189 @@ class OBJECT_PT_onion_skinning(bl_ui.properties_animviz.OnionSkinButtonsPanel):
     bl_options = None
     ''' '''
 
+    bl_parent_id = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
+    bl_rna = None
+    ''' '''
+
     bl_space_type = None
     ''' '''
 
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
         '''
         pass
 
+    def draw_settings(self, _context, avs, mpath, bones):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
     def poll(self, context):
         ''' 
 
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
 
 class ObjectButtonsPanel:
     bl_context = None
@@ -363,6 +590,186 @@ class ObjectButtonsPanel:
     ''' '''
 
 
+class OBJECT_PT_collections(ObjectButtonsPanel, bpy_types.Panel,
+                            bpy_types._GenericUI):
+    bl_context = None
+    ''' '''
+
+    bl_label = None
+    ''' '''
+
+    bl_options = None
+    ''' '''
+
+    bl_region_type = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    bl_space_type = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
 class OBJECT_PT_context_object(ObjectButtonsPanel, bpy_types.Panel,
                                bpy_types._GenericUI):
     bl_context = None
@@ -398,6 +805,18 @@ class OBJECT_PT_context_object(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -434,6 +853,12 @@ class OBJECT_PT_context_object(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -482,12 +907,24 @@ class OBJECT_PT_context_object(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -527,6 +964,9 @@ class OBJECT_PT_custom_props(ObjectButtonsPanel, rna_prop_ui.PropertyPanel,
     bl_options = None
     ''' '''
 
+    bl_order = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
@@ -551,6 +991,18 @@ class OBJECT_PT_custom_props(ObjectButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -587,6 +1039,12 @@ class OBJECT_PT_custom_props(ObjectButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -641,12 +1099,24 @@ class OBJECT_PT_custom_props(ObjectButtonsPanel, rna_prop_ui.PropertyPanel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -683,6 +1153,9 @@ class OBJECT_PT_delta_transform(ObjectButtonsPanel, bpy_types.Panel,
     bl_options = None
     ''' '''
 
+    bl_parent_id = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
@@ -707,6 +1180,18 @@ class OBJECT_PT_delta_transform(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -743,6 +1228,12 @@ class OBJECT_PT_delta_transform(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -791,12 +1282,24 @@ class OBJECT_PT_delta_transform(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -830,6 +1333,12 @@ class OBJECT_PT_display(ObjectButtonsPanel, bpy_types.Panel,
     bl_label = None
     ''' '''
 
+    bl_options = None
+    ''' '''
+
+    bl_order = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
@@ -854,6 +1363,18 @@ class OBJECT_PT_display(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -890,6 +1411,12 @@ class OBJECT_PT_display(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -938,12 +1465,24 @@ class OBJECT_PT_display(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -969,14 +1508,20 @@ class OBJECT_PT_display(ObjectButtonsPanel, bpy_types.Panel,
         pass
 
 
-class OBJECT_PT_duplication(ObjectButtonsPanel, bpy_types.Panel,
-                            bpy_types._GenericUI):
+class OBJECT_PT_display_bounds(ObjectButtonsPanel, bpy_types.Panel,
+                               bpy_types._GenericUI):
     bl_context = None
     ''' '''
 
     bl_label = None
     ''' '''
 
+    bl_options = None
+    ''' '''
+
+    bl_parent_id = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
@@ -1001,12 +1546,30 @@ class OBJECT_PT_duplication(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
         '''
         pass
 
+    def draw_header(self, context):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1037,6 +1600,12 @@ class OBJECT_PT_duplication(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1085,12 +1654,24 @@ class OBJECT_PT_duplication(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1116,14 +1697,17 @@ class OBJECT_PT_duplication(ObjectButtonsPanel, bpy_types.Panel,
         pass
 
 
-class OBJECT_PT_groups(ObjectButtonsPanel, bpy_types.Panel,
-                       bpy_types._GenericUI):
+class OBJECT_PT_instancing(ObjectButtonsPanel, bpy_types.Panel,
+                           bpy_types._GenericUI):
     bl_context = None
     ''' '''
 
     bl_label = None
     ''' '''
 
+    bl_options = None
+    ''' '''
+
     bl_region_type = None
     ''' '''
 
@@ -1148,6 +1732,18 @@ class OBJECT_PT_groups(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -1184,6 +1780,12 @@ class OBJECT_PT_groups(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1232,12 +1834,216 @@ class OBJECT_PT_groups(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class OBJECT_PT_instancing_size(ObjectButtonsPanel, bpy_types.Panel,
+                                bpy_types._GenericUI):
+    bl_context = None
+    ''' '''
+
+    bl_label = None
+    ''' '''
+
+    bl_parent_id = None
+    ''' '''
+
+    bl_region_type = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    bl_space_type = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def draw_header(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1271,153 +2077,6 @@ class OBJECT_PT_relations(ObjectButtonsPanel, bpy_types.Panel,
     bl_label = None
     ''' '''
 
-    bl_region_type = None
-    ''' '''
-
-    bl_rna = None
-    ''' '''
-
-    bl_space_type = None
-    ''' '''
-
-    id_data = None
-    ''' '''
-
-    def append(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def as_pointer(self):
-        ''' 
-
-        '''
-        pass
-
-    def draw(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def driver_add(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_remove(self):
-        ''' 
-
-        '''
-        pass
-
-    def get(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_extended(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_hidden(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_readonly(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def items(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_delete(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_insert(self):
-        ''' 
-
-        '''
-        pass
-
-    def keys(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_from_id(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_resolve(self):
-        ''' 
-
-        '''
-        pass
-
-    def prepend(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def property_unset(self):
-        ''' 
-
-        '''
-        pass
-
-    def remove(self, draw_func):
-        ''' 
-
-        '''
-        pass
-
-    def type_recast(self):
-        ''' 
-
-        '''
-        pass
-
-    def values(self):
-        ''' 
-
-        '''
-        pass
-
-
-class OBJECT_PT_relations_extras(ObjectButtonsPanel, bpy_types.Panel,
-                                 bpy_types._GenericUI):
-    bl_context = None
-    ''' '''
-
-    bl_label = None
-    ''' '''
-
     bl_options = None
     ''' '''
 
@@ -1445,6 +2104,18 @@ class OBJECT_PT_relations_extras(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -1481,6 +2152,12 @@ class OBJECT_PT_relations_extras(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1529,12 +2206,24 @@ class OBJECT_PT_relations_extras(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1592,6 +2281,18 @@ class OBJECT_PT_transform(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -1628,6 +2329,12 @@ class OBJECT_PT_transform(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1676,12 +2383,24 @@ class OBJECT_PT_transform(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -1707,8 +2426,11 @@ class OBJECT_PT_transform(ObjectButtonsPanel, bpy_types.Panel,
         pass
 
 
-class OBJECT_PT_transform_locks(ObjectButtonsPanel, bpy_types.Panel,
-                                bpy_types._GenericUI):
+class OBJECT_PT_visibility(ObjectButtonsPanel, bpy_types.Panel,
+                           bpy_types._GenericUI):
+    COMPAT_ENGINES = None
+    ''' '''
+
     bl_context = None
     ''' '''
 
@@ -1742,6 +2464,18 @@ class OBJECT_PT_transform_locks(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def draw(self, context):
         ''' 
 
@@ -1778,6 +2512,12 @@ class OBJECT_PT_transform_locks(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -1826,12 +2566,30 @@ class OBJECT_PT_transform_locks(ObjectButtonsPanel, bpy_types.Panel,
         '''
         pass
 
+    def poll(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
     def prepend(self, draw_func):
         ''' 
 
         '''
         pass
 
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
