@@ -1,14 +1,15 @@
 import sys
 import typing
-from . import ops
+import bpy.types
+
 from . import types
+from . import ops
 from . import app
-from . import path
-from . import utils
-from . import props
 from . import context
+from . import props
+from . import utils
+from . import path
 
-context: 'types.Context' = None
-
-data: 'types.BlendData' = None
-'''Access to Blenders internal data '''
+data: 'bpy.types.BlendData' = None
+''' Access to Blender's internal data
+'''
