@@ -1,11 +1,12 @@
 import sys
 import typing
+import bpy.types
 
 
 def cyclic_toggle(direction: typing.Union[str, int] = 'CYCLIC_U'):
-    '''Make active spline closed/opened loop 
+    ''' Make active spline closed/opened loop
 
-    :param direction: Direction, Direction to make surface cyclic in 
+    :param direction: Direction, Direction to make surface cyclic in
     :type direction: typing.Union[str, int]
     '''
 
@@ -13,7 +14,7 @@ def cyclic_toggle(direction: typing.Union[str, int] = 'CYCLIC_U'):
 
 
 def de_select_first():
-    '''(De)select first of visible part of each NURBS 
+    ''' (De)select first of visible part of each NURBS
 
     '''
 
@@ -21,7 +22,7 @@ def de_select_first():
 
 
 def de_select_last():
-    '''(De)select last of visible part of each NURBS 
+    ''' (De)select last of visible part of each NURBS
 
     '''
 
@@ -29,9 +30,9 @@ def de_select_last():
 
 
 def decimate(ratio: float = 1.0):
-    '''Simplify selected curves 
+    ''' Simplify selected curves
 
-    :param ratio: Ratio 
+    :param ratio: Ratio
     :type ratio: float
     '''
 
@@ -39,9 +40,9 @@ def decimate(ratio: float = 1.0):
 
 
 def delete(type: typing.Union[str, int] = 'VERT'):
-    '''Delete selected control points or segments 
+    ''' Delete selected control points or segments
 
-    :param type: Type, Which elements to delete 
+    :param type: Type, Which elements to delete
     :type type: typing.Union[str, int]
     '''
 
@@ -49,7 +50,7 @@ def delete(type: typing.Union[str, int] = 'VERT'):
 
 
 def dissolve_verts():
-    '''Delete selected control points, correcting surrounding handles 
+    ''' Delete selected control points, correcting surrounding handles
 
     '''
 
@@ -63,19 +64,19 @@ def draw(error_threshold: float = 0.0,
          stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'],
                               'bpy_prop_collection'] = None,
          wait_for_input: bool = True):
-    '''Draw a freehand spline 
+    ''' Draw a freehand spline
 
-    :param error_threshold: Error, Error distance threshold (in object units) 
+    :param error_threshold: Error, Error distance threshold (in object units)
     :type error_threshold: float
-    :param fit_method: Fit MethodREFIT Refit, Incrementally re-fit the curve (high quality).SPLIT Split, Split the curve until the tolerance is met (fast). 
+    :param fit_method: Fit Method * REFIT Refit, Incrementally re-fit the curve (high quality). * SPLIT Split, Split the curve until the tolerance is met (fast).
     :type fit_method: typing.Union[str, int]
-    :param corner_angle: Corner Angle 
+    :param corner_angle: Corner Angle
     :type corner_angle: float
-    :param use_cyclic: Cyclic 
+    :param use_cyclic: Cyclic
     :type use_cyclic: bool
-    :param stroke: Stroke 
+    :param stroke: Stroke
     :type stroke: typing.Union[typing.List['bpy.types.OperatorStrokeElement'], 'bpy_prop_collection']
-    :param wait_for_input: Wait for Input 
+    :param wait_for_input: Wait for Input
     :type wait_for_input: bool
     '''
 
@@ -83,7 +84,7 @@ def draw(error_threshold: float = 0.0,
 
 
 def duplicate():
-    '''Duplicate selected control points 
+    ''' Duplicate selected control points
 
     '''
 
@@ -91,19 +92,19 @@ def duplicate():
 
 
 def duplicate_move(CURVE_OT_duplicate=None, TRANSFORM_OT_translate=None):
-    '''Duplicate curve and move 
+    ''' Duplicate curve and move
 
-    :param CURVE_OT_duplicate: Duplicate Curve, Duplicate selected control points 
-    :param TRANSFORM_OT_translate: Move, Move selected items 
+    :param CURVE_OT_duplicate: Duplicate Curve, Duplicate selected control points
+    :param TRANSFORM_OT_translate: Move, Move selected items
     '''
 
     pass
 
 
 def extrude(mode: typing.Union[str, int] = 'TRANSLATION'):
-    '''Extrude selected control point(s) 
+    ''' Extrude selected control point(s)
 
-    :param mode: Mode 
+    :param mode: Mode
     :type mode: typing.Union[str, int]
     '''
 
@@ -111,19 +112,19 @@ def extrude(mode: typing.Union[str, int] = 'TRANSLATION'):
 
 
 def extrude_move(CURVE_OT_extrude=None, TRANSFORM_OT_translate=None):
-    '''Extrude curve and move result 
+    ''' Extrude curve and move result
 
-    :param CURVE_OT_extrude: Extrude, Extrude selected control point(s) 
-    :param TRANSFORM_OT_translate: Move, Move selected items 
+    :param CURVE_OT_extrude: Extrude, Extrude selected control point(s)
+    :param TRANSFORM_OT_translate: Move, Move selected items
     '''
 
     pass
 
 
 def handle_type_set(type: typing.Union[str, int] = 'AUTOMATIC'):
-    '''Set type of handles for selected control points 
+    ''' Set type of handles for selected control points
 
-    :param type: Type, Spline type 
+    :param type: Type, Spline type
     :type type: typing.Union[str, int]
     '''
 
@@ -131,9 +132,9 @@ def handle_type_set(type: typing.Union[str, int] = 'AUTOMATIC'):
 
 
 def hide(unselected: bool = False):
-    '''Hide (un)selected control points 
+    ''' Hide (un)selected control points
 
-    :param unselected: Unselected, Hide unselected rather than selected 
+    :param unselected: Unselected, Hide unselected rather than selected
     :type unselected: bool
     '''
 
@@ -141,7 +142,7 @@ def hide(unselected: bool = False):
 
 
 def make_segment():
-    '''Join two curves by their selected ends 
+    ''' Join two curves by their selected ends
 
     '''
 
@@ -149,7 +150,7 @@ def make_segment():
 
 
 def match_texture_space():
-    '''Match texture space to object’s bounding box 
+    ''' Match texture space to object's bounding box
 
     '''
 
@@ -157,9 +158,9 @@ def match_texture_space():
 
 
 def normals_make_consistent(calc_length: bool = False):
-    '''Recalculate the direction of selected handles 
+    ''' Recalculate the direction of selected handles
 
-    :param calc_length: Length, Recalculate handle length 
+    :param calc_length: Length, Recalculate handle length
     :type calc_length: bool
     '''
 
@@ -172,17 +173,17 @@ def primitive_bezier_circle_add(radius: float = 1.0,
                                 location: typing.List[float] = (0.0, 0.0, 0.0),
                                 rotation: typing.List[float] = (0.0, 0.0,
                                                                 0.0)):
-    '''Construct a Bezier Circle 
+    ''' Construct a Bezier Circle
 
-    :param radius: Radius 
+    :param radius: Radius
     :type radius: float
-    :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
+    :param enter_editmode: Enter Editmode, Enter editmode when adding this object
     :type enter_editmode: bool
-    :param align: Align, The alignment of the new objectWORLD World, Align the new object to the world.VIEW View, Align the new object to the view.CURSOR 3D Cursor, Use the 3D cursor orientation for the new object. 
+    :param align: Align, The alignment of the new object * WORLD World, Align the new object to the world. * VIEW View, Align the new object to the view. * CURSOR 3D Cursor, Use the 3D cursor orientation for the new object.
     :type align: typing.Union[str, int]
-    :param location: Location, Location for the newly added object 
+    :param location: Location, Location for the newly added object
     :type location: typing.List[float]
-    :param rotation: Rotation, Rotation for the newly added object 
+    :param rotation: Rotation, Rotation for the newly added object
     :type rotation: typing.List[float]
     '''
 
@@ -194,17 +195,17 @@ def primitive_bezier_curve_add(radius: float = 1.0,
                                align: typing.Union[str, int] = 'WORLD',
                                location: typing.List[float] = (0.0, 0.0, 0.0),
                                rotation: typing.List[float] = (0.0, 0.0, 0.0)):
-    '''Construct a Bezier Curve 
+    ''' Construct a Bezier Curve
 
-    :param radius: Radius 
+    :param radius: Radius
     :type radius: float
-    :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
+    :param enter_editmode: Enter Editmode, Enter editmode when adding this object
     :type enter_editmode: bool
-    :param align: Align, The alignment of the new objectWORLD World, Align the new object to the world.VIEW View, Align the new object to the view.CURSOR 3D Cursor, Use the 3D cursor orientation for the new object. 
+    :param align: Align, The alignment of the new object * WORLD World, Align the new object to the world. * VIEW View, Align the new object to the view. * CURSOR 3D Cursor, Use the 3D cursor orientation for the new object.
     :type align: typing.Union[str, int]
-    :param location: Location, Location for the newly added object 
+    :param location: Location, Location for the newly added object
     :type location: typing.List[float]
-    :param rotation: Rotation, Rotation for the newly added object 
+    :param rotation: Rotation, Rotation for the newly added object
     :type rotation: typing.List[float]
     '''
 
@@ -216,17 +217,17 @@ def primitive_nurbs_circle_add(radius: float = 1.0,
                                align: typing.Union[str, int] = 'WORLD',
                                location: typing.List[float] = (0.0, 0.0, 0.0),
                                rotation: typing.List[float] = (0.0, 0.0, 0.0)):
-    '''Construct a Nurbs Circle 
+    ''' Construct a Nurbs Circle
 
-    :param radius: Radius 
+    :param radius: Radius
     :type radius: float
-    :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
+    :param enter_editmode: Enter Editmode, Enter editmode when adding this object
     :type enter_editmode: bool
-    :param align: Align, The alignment of the new objectWORLD World, Align the new object to the world.VIEW View, Align the new object to the view.CURSOR 3D Cursor, Use the 3D cursor orientation for the new object. 
+    :param align: Align, The alignment of the new object * WORLD World, Align the new object to the world. * VIEW View, Align the new object to the view. * CURSOR 3D Cursor, Use the 3D cursor orientation for the new object.
     :type align: typing.Union[str, int]
-    :param location: Location, Location for the newly added object 
+    :param location: Location, Location for the newly added object
     :type location: typing.List[float]
-    :param rotation: Rotation, Rotation for the newly added object 
+    :param rotation: Rotation, Rotation for the newly added object
     :type rotation: typing.List[float]
     '''
 
@@ -238,17 +239,17 @@ def primitive_nurbs_curve_add(radius: float = 1.0,
                               align: typing.Union[str, int] = 'WORLD',
                               location: typing.List[float] = (0.0, 0.0, 0.0),
                               rotation: typing.List[float] = (0.0, 0.0, 0.0)):
-    '''Construct a Nurbs Curve 
+    ''' Construct a Nurbs Curve
 
-    :param radius: Radius 
+    :param radius: Radius
     :type radius: float
-    :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
+    :param enter_editmode: Enter Editmode, Enter editmode when adding this object
     :type enter_editmode: bool
-    :param align: Align, The alignment of the new objectWORLD World, Align the new object to the world.VIEW View, Align the new object to the view.CURSOR 3D Cursor, Use the 3D cursor orientation for the new object. 
+    :param align: Align, The alignment of the new object * WORLD World, Align the new object to the world. * VIEW View, Align the new object to the view. * CURSOR 3D Cursor, Use the 3D cursor orientation for the new object.
     :type align: typing.Union[str, int]
-    :param location: Location, Location for the newly added object 
+    :param location: Location, Location for the newly added object
     :type location: typing.List[float]
-    :param rotation: Rotation, Rotation for the newly added object 
+    :param rotation: Rotation, Rotation for the newly added object
     :type rotation: typing.List[float]
     '''
 
@@ -260,17 +261,17 @@ def primitive_nurbs_path_add(radius: float = 1.0,
                              align: typing.Union[str, int] = 'WORLD',
                              location: typing.List[float] = (0.0, 0.0, 0.0),
                              rotation: typing.List[float] = (0.0, 0.0, 0.0)):
-    '''Construct a Path 
+    ''' Construct a Path
 
-    :param radius: Radius 
+    :param radius: Radius
     :type radius: float
-    :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
+    :param enter_editmode: Enter Editmode, Enter editmode when adding this object
     :type enter_editmode: bool
-    :param align: Align, The alignment of the new objectWORLD World, Align the new object to the world.VIEW View, Align the new object to the view.CURSOR 3D Cursor, Use the 3D cursor orientation for the new object. 
+    :param align: Align, The alignment of the new object * WORLD World, Align the new object to the world. * VIEW View, Align the new object to the view. * CURSOR 3D Cursor, Use the 3D cursor orientation for the new object.
     :type align: typing.Union[str, int]
-    :param location: Location, Location for the newly added object 
+    :param location: Location, Location for the newly added object
     :type location: typing.List[float]
-    :param rotation: Rotation, Rotation for the newly added object 
+    :param rotation: Rotation, Rotation for the newly added object
     :type rotation: typing.List[float]
     '''
 
@@ -278,9 +279,9 @@ def primitive_nurbs_path_add(radius: float = 1.0,
 
 
 def radius_set(radius: float = 1.0):
-    '''Set per-point radius which is used for bevel tapering 
+    ''' Set per-point radius which is used for bevel tapering
 
-    :param radius: Radius 
+    :param radius: Radius
     :type radius: float
     '''
 
@@ -288,9 +289,9 @@ def radius_set(radius: float = 1.0):
 
 
 def reveal(select: bool = True):
-    '''Reveal hidden control points 
+    ''' Reveal hidden control points
 
-    :param select: Select 
+    :param select: Select
     :type select: bool
     '''
 
@@ -298,9 +299,9 @@ def reveal(select: bool = True):
 
 
 def select_all(action: typing.Union[str, int] = 'TOGGLE'):
-    '''(De)select all control points 
+    ''' (De)select all control points
 
-    :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
+    :param action: Action, Selection action to execute * TOGGLE Toggle, Toggle selection for all elements. * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements. * INVERT Invert, Invert selection of all elements.
     :type action: typing.Union[str, int]
     '''
 
@@ -308,7 +309,7 @@ def select_all(action: typing.Union[str, int] = 'TOGGLE'):
 
 
 def select_less():
-    '''Reduce current selection by deselecting boundary elements 
+    ''' Reduce current selection by deselecting boundary elements
 
     '''
 
@@ -316,7 +317,7 @@ def select_less():
 
 
 def select_linked():
-    '''Select all control points linked to the current selection 
+    ''' Select all control points linked to the current selection
 
     '''
 
@@ -324,9 +325,9 @@ def select_linked():
 
 
 def select_linked_pick(deselect: bool = False):
-    '''Select all control points linked to already selected ones 
+    ''' Select all control points linked to already selected ones
 
-    :param deselect: Deselect, Deselect linked control points rather than selecting them 
+    :param deselect: Deselect, Deselect linked control points rather than selecting them
     :type deselect: bool
     '''
 
@@ -334,7 +335,7 @@ def select_linked_pick(deselect: bool = False):
 
 
 def select_more():
-    '''Select control points directly linked to already selected ones 
+    ''' Select control points directly linked to already selected ones
 
     '''
 
@@ -342,7 +343,7 @@ def select_more():
 
 
 def select_next():
-    '''Select control points following already selected ones along the curves 
+    ''' Select control points following already selected ones along the curves
 
     '''
 
@@ -350,13 +351,13 @@ def select_next():
 
 
 def select_nth(skip: int = 1, nth: int = 1, offset: int = 0):
-    '''Deselect every Nth point starting from the active one 
+    ''' Deselect every Nth point starting from the active one
 
-    :param skip: Deselected, Number of deselected elements in the repetitive sequence 
+    :param skip: Deselected, Number of deselected elements in the repetitive sequence
     :type skip: int
-    :param nth: Selected, Number of selected elements in the repetitive sequence 
+    :param nth: Selected, Number of selected elements in the repetitive sequence
     :type nth: int
-    :param offset: Offset, Offset from the starting point 
+    :param offset: Offset, Offset from the starting point
     :type offset: int
     '''
 
@@ -364,7 +365,7 @@ def select_nth(skip: int = 1, nth: int = 1, offset: int = 0):
 
 
 def select_previous():
-    '''Select control points preceding already selected ones along the curves 
+    ''' Select control points preceding already selected ones along the curves
 
     '''
 
@@ -374,13 +375,13 @@ def select_previous():
 def select_random(percent: float = 50.0,
                   seed: int = 0,
                   action: typing.Union[str, int] = 'SELECT'):
-    '''Randomly select some control points 
+    ''' Randomly select some control points
 
-    :param percent: Percent, Percentage of objects to select randomly 
+    :param percent: Percent, Percentage of objects to select randomly
     :type percent: float
-    :param seed: Random Seed, Seed for the random number generator 
+    :param seed: Random Seed, Seed for the random number generator
     :type seed: int
-    :param action: Action, Selection action to executeSELECT Select, Select all elements.DESELECT Deselect, Deselect all elements. 
+    :param action: Action, Selection action to execute * SELECT Select, Select all elements. * DESELECT Deselect, Deselect all elements.
     :type action: typing.Union[str, int]
     '''
 
@@ -388,7 +389,7 @@ def select_random(percent: float = 50.0,
 
 
 def select_row():
-    '''Select a row of control points including active one 
+    ''' Select a row of control points including active one
 
     '''
 
@@ -398,13 +399,13 @@ def select_row():
 def select_similar(type: typing.Union[str, int] = 'WEIGHT',
                    compare: typing.Union[str, int] = 'EQUAL',
                    threshold: float = 0.1):
-    '''Select similar curve points by property type 
+    ''' Select similar curve points by property type
 
-    :param type: Type 
+    :param type: Type
     :type type: typing.Union[str, int]
-    :param compare: Compare 
+    :param compare: Compare
     :type compare: typing.Union[str, int]
-    :param threshold: Threshold 
+    :param threshold: Threshold
     :type threshold: float
     '''
 
@@ -412,7 +413,7 @@ def select_similar(type: typing.Union[str, int] = 'WEIGHT',
 
 
 def separate():
-    '''Separate selected points from connected unselected points into a new object 
+    ''' Separate selected points from connected unselected points into a new object
 
     '''
 
@@ -420,7 +421,7 @@ def separate():
 
 
 def shade_flat():
-    '''Set shading to flat 
+    ''' Set shading to flat
 
     '''
 
@@ -428,7 +429,7 @@ def shade_flat():
 
 
 def shade_smooth():
-    '''Set shading to smooth 
+    ''' Set shading to smooth
 
     '''
 
@@ -436,7 +437,7 @@ def shade_smooth():
 
 
 def shortest_path_pick():
-    '''Select shortest path between two selections 
+    ''' Select shortest path between two selections
 
     '''
 
@@ -444,7 +445,7 @@ def shortest_path_pick():
 
 
 def smooth():
-    '''Flatten angles of selected points 
+    ''' Flatten angles of selected points
 
     '''
 
@@ -452,7 +453,7 @@ def smooth():
 
 
 def smooth_radius():
-    '''Interpolate radii of selected points 
+    ''' Interpolate radii of selected points
 
     '''
 
@@ -460,7 +461,7 @@ def smooth_radius():
 
 
 def smooth_tilt():
-    '''Interpolate tilt of selected points 
+    ''' Interpolate tilt of selected points
 
     '''
 
@@ -468,7 +469,7 @@ def smooth_tilt():
 
 
 def smooth_weight():
-    '''Interpolate weight of selected points 
+    ''' Interpolate weight of selected points
 
     '''
 
@@ -477,11 +478,11 @@ def smooth_weight():
 
 def spin(center: typing.List[float] = (0.0, 0.0, 0.0),
          axis: typing.List[float] = (0.0, 0.0, 0.0)):
-    '''Extrude selected boundary row around pivot point and current view axis 
+    ''' Extrude selected boundary row around pivot point and current view axis
 
-    :param center: Center, Center in global view space 
+    :param center: Center, Center in global view space
     :type center: typing.List[float]
-    :param axis: Axis, Axis in global view space 
+    :param axis: Axis, Axis in global view space
     :type axis: typing.List[float]
     '''
 
@@ -490,11 +491,11 @@ def spin(center: typing.List[float] = (0.0, 0.0, 0.0),
 
 def spline_type_set(type: typing.Union[str, int] = 'POLY',
                     use_handles: bool = False):
-    '''Set type of active spline 
+    ''' Set type of active spline
 
-    :param type: Type, Spline type 
+    :param type: Type, Spline type
     :type type: typing.Union[str, int]
-    :param use_handles: Handles, Use handles when converting bezier curves into polygons 
+    :param use_handles: Handles, Use handles when converting bezier curves into polygons
     :type use_handles: bool
     '''
 
@@ -502,9 +503,9 @@ def spline_type_set(type: typing.Union[str, int] = 'POLY',
 
 
 def spline_weight_set(weight: float = 1.0):
-    '''Set softbody goal weight for selected points 
+    ''' Set softbody goal weight for selected points
 
-    :param weight: Weight 
+    :param weight: Weight
     :type weight: float
     '''
 
@@ -512,7 +513,7 @@ def spline_weight_set(weight: float = 1.0):
 
 
 def split():
-    '''Split off selected points from connected unselected points 
+    ''' Split off selected points from connected unselected points
 
     '''
 
@@ -520,9 +521,9 @@ def split():
 
 
 def subdivide(number_cuts: int = 1):
-    '''Subdivide selected segments 
+    ''' Subdivide selected segments
 
-    :param number_cuts: Number of cuts 
+    :param number_cuts: Number of cuts
     :type number_cuts: int
     '''
 
@@ -530,7 +531,7 @@ def subdivide(number_cuts: int = 1):
 
 
 def switch_direction():
-    '''Switch direction of selected splines 
+    ''' Switch direction of selected splines
 
     '''
 
@@ -538,7 +539,7 @@ def switch_direction():
 
 
 def tilt_clear():
-    '''Clear the tilt of selected control points 
+    ''' Clear the tilt of selected control points
 
     '''
 
@@ -546,9 +547,9 @@ def tilt_clear():
 
 
 def vertex_add(location: typing.List[float] = (0.0, 0.0, 0.0)):
-    '''Add a new control point (linked to only selected end-curve one, if any) 
+    ''' Add a new control point (linked to only selected end-curve one, if any)
 
-    :param location: Location, Location to add new vertex at 
+    :param location: Location, Location to add new vertex at
     :type location: typing.List[float]
     '''
 
