@@ -3,9 +3,9 @@ import typing
 
 
 def case_set(case: typing.Union[str, int] = 'LOWER'):
-    '''Set font case 
+    ''' Set font case
 
-    :param case: Case, Lower or upper case 
+    :param case: Case, Lower or upper case
     :type case: typing.Union[str, int]
     '''
 
@@ -13,7 +13,7 @@ def case_set(case: typing.Union[str, int] = 'LOWER'):
 
 
 def case_toggle():
-    '''Toggle font case 
+    ''' Toggle font case
 
     '''
 
@@ -21,9 +21,9 @@ def case_toggle():
 
 
 def change_character(delta: int = 1):
-    '''Change font character code 
+    ''' Change font character code
 
-    :param delta: Delta, Number to increase or decrease character code with 
+    :param delta: Delta, Number to increase or decrease character code with
     :type delta: int
     '''
 
@@ -31,9 +31,9 @@ def change_character(delta: int = 1):
 
 
 def change_spacing(delta: int = 1):
-    '''Change font spacing 
+    ''' Change font spacing
 
-    :param delta: Delta, Amount to decrease or increase character spacing with 
+    :param delta: Delta, Amount to decrease or increase character spacing with
     :type delta: int
     '''
 
@@ -41,9 +41,9 @@ def change_spacing(delta: int = 1):
 
 
 def delete(type: typing.Union[str, int] = 'PREVIOUS_CHARACTER'):
-    '''Delete text by cursor position 
+    ''' Delete text by cursor position
 
-    :param type: Type, Which part of the text to delete 
+    :param type: Type, Which part of the text to delete
     :type type: typing.Union[str, int]
     '''
 
@@ -51,7 +51,7 @@ def delete(type: typing.Union[str, int] = 'PREVIOUS_CHARACTER'):
 
 
 def line_break():
-    '''Insert line break at cursor position 
+    ''' Insert line break at cursor position
 
     '''
 
@@ -59,9 +59,9 @@ def line_break():
 
 
 def move(type: typing.Union[str, int] = 'LINE_BEGIN'):
-    '''Move cursor to position type 
+    ''' Move cursor to position type
 
-    :param type: Type, Where to move cursor to 
+    :param type: Type, Where to move cursor to
     :type type: typing.Union[str, int]
     '''
 
@@ -69,9 +69,9 @@ def move(type: typing.Union[str, int] = 'LINE_BEGIN'):
 
 
 def move_select(type: typing.Union[str, int] = 'LINE_BEGIN'):
-    '''Move the cursor while selecting 
+    ''' Move the cursor while selecting
 
-    :param type: Type, Where to move cursor to, to make a selection 
+    :param type: Type, Where to move cursor to, to make a selection
     :type type: typing.Union[str, int]
     '''
 
@@ -99,49 +99,49 @@ def open(filepath: str = "",
          relative_path: bool = True,
          display_type: typing.Union[str, int] = 'DEFAULT',
          sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
-    '''Load a new font from a file 
+    ''' Load a new font from a file
 
-    :param filepath: File Path, Path to file 
+    :param filepath: File Path, Path to file
     :type filepath: str
-    :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings 
+    :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
     :type hide_props_region: bool
-    :param filter_blender: Filter .blend files 
+    :param filter_blender: Filter .blend files
     :type filter_blender: bool
-    :param filter_backup: Filter .blend files 
+    :param filter_backup: Filter .blend files
     :type filter_backup: bool
-    :param filter_image: Filter image files 
+    :param filter_image: Filter image files
     :type filter_image: bool
-    :param filter_movie: Filter movie files 
+    :param filter_movie: Filter movie files
     :type filter_movie: bool
-    :param filter_python: Filter python files 
+    :param filter_python: Filter python files
     :type filter_python: bool
-    :param filter_font: Filter font files 
+    :param filter_font: Filter font files
     :type filter_font: bool
-    :param filter_sound: Filter sound files 
+    :param filter_sound: Filter sound files
     :type filter_sound: bool
-    :param filter_text: Filter text files 
+    :param filter_text: Filter text files
     :type filter_text: bool
-    :param filter_archive: Filter archive files 
+    :param filter_archive: Filter archive files
     :type filter_archive: bool
-    :param filter_btx: Filter btx files 
+    :param filter_btx: Filter btx files
     :type filter_btx: bool
-    :param filter_collada: Filter COLLADA files 
+    :param filter_collada: Filter COLLADA files
     :type filter_collada: bool
-    :param filter_alembic: Filter Alembic files 
+    :param filter_alembic: Filter Alembic files
     :type filter_alembic: bool
-    :param filter_usd: Filter USD files 
+    :param filter_usd: Filter USD files
     :type filter_usd: bool
-    :param filter_folder: Filter folders 
+    :param filter_folder: Filter folders
     :type filter_folder: bool
-    :param filter_blenlib: Filter Blender IDs 
+    :param filter_blenlib: Filter Blender IDs
     :type filter_blenlib: bool
-    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
+    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
-    :param relative_path: Relative Path, Select the file relative to the blend file 
+    :param relative_path: Relative Path, Select the file relative to the blend file
     :type relative_path: bool
-    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_VERTICAL Short List, Display files as short list.LIST_HORIZONTAL Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
+    :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
     :type display_type: typing.Union[str, int]
-    :param sort_method: File sorting modeFILE_SORT_ALPHA Name, Sort the file list alphabetically.FILE_SORT_EXTENSION Extension, Sort the file list by extension/type.FILE_SORT_TIME Modified Date, Sort files by modification time.FILE_SORT_SIZE Size, Sort files by size. 
+    :param sort_method: File sorting mode * FILE_SORT_ALPHA Name, Sort the file list alphabetically. * FILE_SORT_EXTENSION Extension, Sort the file list by extension/type. * FILE_SORT_TIME Modified Date, Sort files by modification time. * FILE_SORT_SIZE Size, Sort files by size.
     :type sort_method: typing.Union[str, int]
     '''
 
@@ -149,7 +149,7 @@ def open(filepath: str = "",
 
 
 def select_all():
-    '''Select all text 
+    ''' Select all text
 
     '''
 
@@ -157,11 +157,11 @@ def select_all():
 
 
 def style_set(style: typing.Union[str, int] = 'BOLD', clear: bool = False):
-    '''Set font style 
+    ''' Set font style
 
-    :param style: Style, Style to set selection to 
+    :param style: Style, Style to set selection to
     :type style: typing.Union[str, int]
-    :param clear: Clear, Clear style rather than setting it 
+    :param clear: Clear, Clear style rather than setting it
     :type clear: bool
     '''
 
@@ -169,9 +169,9 @@ def style_set(style: typing.Union[str, int] = 'BOLD', clear: bool = False):
 
 
 def style_toggle(style: typing.Union[str, int] = 'BOLD'):
-    '''Toggle font style 
+    ''' Toggle font style
 
-    :param style: Style, Style to set selection to 
+    :param style: Style, Style to set selection to
     :type style: typing.Union[str, int]
     '''
 
@@ -179,7 +179,7 @@ def style_toggle(style: typing.Union[str, int] = 'BOLD'):
 
 
 def text_copy():
-    '''Copy selected text to clipboard 
+    ''' Copy selected text to clipboard
 
     '''
 
@@ -187,7 +187,7 @@ def text_copy():
 
 
 def text_cut():
-    '''Cut selected text to clipboard 
+    ''' Cut selected text to clipboard
 
     '''
 
@@ -195,11 +195,11 @@ def text_cut():
 
 
 def text_insert(text: str = "", accent: bool = False):
-    '''Insert text at cursor position 
+    ''' Insert text at cursor position
 
-    :param text: Text, Text to insert at the cursor position 
+    :param text: Text, Text to insert at the cursor position
     :type text: str
-    :param accent: Accent mode, Next typed character will strike through previous, for special character input 
+    :param accent: Accent mode, Next typed character will strike through previous, for special character input
     :type accent: bool
     '''
 
@@ -207,7 +207,7 @@ def text_insert(text: str = "", accent: bool = False):
 
 
 def text_paste():
-    '''Paste text from clipboard 
+    ''' Paste text from clipboard
 
     '''
 
@@ -235,47 +235,47 @@ def text_paste_from_file(
         filemode: int = 9,
         display_type: typing.Union[str, int] = 'DEFAULT',
         sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
-    '''Paste contents from file 
+    ''' Paste contents from file
 
-    :param filepath: File Path, Path to file 
+    :param filepath: File Path, Path to file
     :type filepath: str
-    :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings 
+    :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
     :type hide_props_region: bool
-    :param filter_blender: Filter .blend files 
+    :param filter_blender: Filter .blend files
     :type filter_blender: bool
-    :param filter_backup: Filter .blend files 
+    :param filter_backup: Filter .blend files
     :type filter_backup: bool
-    :param filter_image: Filter image files 
+    :param filter_image: Filter image files
     :type filter_image: bool
-    :param filter_movie: Filter movie files 
+    :param filter_movie: Filter movie files
     :type filter_movie: bool
-    :param filter_python: Filter python files 
+    :param filter_python: Filter python files
     :type filter_python: bool
-    :param filter_font: Filter font files 
+    :param filter_font: Filter font files
     :type filter_font: bool
-    :param filter_sound: Filter sound files 
+    :param filter_sound: Filter sound files
     :type filter_sound: bool
-    :param filter_text: Filter text files 
+    :param filter_text: Filter text files
     :type filter_text: bool
-    :param filter_archive: Filter archive files 
+    :param filter_archive: Filter archive files
     :type filter_archive: bool
-    :param filter_btx: Filter btx files 
+    :param filter_btx: Filter btx files
     :type filter_btx: bool
-    :param filter_collada: Filter COLLADA files 
+    :param filter_collada: Filter COLLADA files
     :type filter_collada: bool
-    :param filter_alembic: Filter Alembic files 
+    :param filter_alembic: Filter Alembic files
     :type filter_alembic: bool
-    :param filter_usd: Filter USD files 
+    :param filter_usd: Filter USD files
     :type filter_usd: bool
-    :param filter_folder: Filter folders 
+    :param filter_folder: Filter folders
     :type filter_folder: bool
-    :param filter_blenlib: Filter Blender IDs 
+    :param filter_blenlib: Filter Blender IDs
     :type filter_blenlib: bool
-    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
+    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
     :type filemode: int
-    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_VERTICAL Short List, Display files as short list.LIST_HORIZONTAL Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
+    :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_VERTICAL Short List, Display files as short list. * LIST_HORIZONTAL Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
     :type display_type: typing.Union[str, int]
-    :param sort_method: File sorting modeFILE_SORT_ALPHA Name, Sort the file list alphabetically.FILE_SORT_EXTENSION Extension, Sort the file list by extension/type.FILE_SORT_TIME Modified Date, Sort files by modification time.FILE_SORT_SIZE Size, Sort files by size. 
+    :param sort_method: File sorting mode * FILE_SORT_ALPHA Name, Sort the file list alphabetically. * FILE_SORT_EXTENSION Extension, Sort the file list by extension/type. * FILE_SORT_TIME Modified Date, Sort files by modification time. * FILE_SORT_SIZE Size, Sort files by size.
     :type sort_method: typing.Union[str, int]
     '''
 
@@ -283,7 +283,7 @@ def text_paste_from_file(
 
 
 def textbox_add():
-    '''Add a new text box 
+    ''' Add a new text box
 
     '''
 
@@ -291,9 +291,9 @@ def textbox_add():
 
 
 def textbox_remove(index: int = 0):
-    '''Remove the textbox 
+    ''' Remove the textbox
 
-    :param index: Index, The current text box 
+    :param index: Index, The current text box
     :type index: int
     '''
 
@@ -301,7 +301,7 @@ def textbox_remove(index: int = 0):
 
 
 def unlink():
-    '''Unlink active font data-block 
+    ''' Unlink active font data-block
 
     '''
 
