@@ -1,5 +1,6 @@
 import sys
 import typing
+import bpy.types
 
 
 def ply(filepath: str = "",
@@ -7,15 +8,15 @@ def ply(filepath: str = "",
                             'bpy_prop_collection'] = None,
         directory: str = "",
         filter_glob: str = "*.ply"):
-    '''Load a PLY geometry file 
+    ''' Load a PLY geometry file
 
-    :param filepath: File Path, Filepath used for importing the file 
+    :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
-    :param files: File Path, File path used for importing the PLY file 
+    :param files: File Path, File path used for importing the PLY file
     :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
-    :param directory: directory 
+    :param directory: directory
     :type directory: str
-    :param filter_glob: filter_glob 
+    :param filter_glob: filter_glob
     :type filter_glob: str
     '''
 
@@ -32,25 +33,25 @@ def stl(filepath: str = "",
         use_facet_normal: bool = False,
         axis_forward: typing.Union[str, int] = 'Y',
         axis_up: typing.Union[str, int] = 'Z'):
-    '''Load STL triangle mesh data 
+    ''' Load STL triangle mesh data
 
-    :param filepath: File Path, Filepath used for importing the file 
+    :param filepath: File Path, Filepath used for importing the file
     :type filepath: str
-    :param filter_glob: filter_glob 
+    :param filter_glob: filter_glob
     :type filter_glob: str
-    :param files: File Path 
+    :param files: File Path
     :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
-    :param directory: directory 
+    :param directory: directory
     :type directory: str
-    :param global_scale: Scale 
+    :param global_scale: Scale
     :type global_scale: float
-    :param use_scene_unit: Scene Unit, Apply current scene’s unit (as defined by unit scale) to imported data 
+    :param use_scene_unit: Scene Unit, Apply current scene's unit (as defined by unit scale) to imported data
     :type use_scene_unit: bool
-    :param use_facet_normal: Facet Normals, Use (import) facet normals (note that this will still give flat shading) 
+    :param use_facet_normal: Facet Normals, Use (import) facet normals (note that this will still give flat shading)
     :type use_facet_normal: bool
-    :param axis_forward: Forward 
+    :param axis_forward: Forward
     :type axis_forward: typing.Union[str, int]
-    :param axis_up: Up 
+    :param axis_up: Up
     :type axis_up: typing.Union[str, int]
     '''
 
